=======
 GWOSC
=======

A python interface to the
`Gravitational-Wave Open Science Center <https://gwosc.org>`_ archive.

Installation
------------

``gwosc`` can be installed via `pip <https://pip.pypa.io>`_:

.. code-block:: shell

   python -m pip install gwosc

or `Conda <https://conda.io>`:

.. code-block:: shell

   conda install -c conda-forge gwosc

Documentation
-------------

.. toctree::
   :maxdepth: 1

   datasets
   locate
   timeline
   api

Index
-----

.. toctree::

* :ref:`genindex`
* :ref:`modindex`
